from django.contrib import admin

from wagtailsystemtext.models import SystemString


class SystemStringAdmin(admin.ModelAdmin):
    list_display = ('identifier', 'string', 'group', 'site')

    class Meta:
        model = SystemString

admin.site.register(SystemString, SystemStringAdmin)



from django.utils.deprecation import MiddlewareMixin

from wagtailsystemtext.utils import (
    in_cache, fill_cache, set_site, preload
)


class SiteSystemTextMiddleware(MiddlewareMixin):
    def process_request(self, request):
        site = request.site

        set_site(request.site)

        if not in_cache(site):
            fill_cache(site)

        preload(site)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
wagtailsystemtext
----------
Simplified Wagtail system text management
"""

__title__ = 'wagtailsystemtext'
__version__ = '1.0.3'
__build__ = 103
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2016 Martin Sandström"

default_app_config = 'wagtailsystemtext.apps.WagtailSystemTextConfig'



from django.conf import settings


SYSTEMTEXT_CACHE_PREFIX = getattr(settings, 'SYSTEMTEXT_CACHE_PREFIX',
                                  'wagtailsystemtext')
SYSTEMTEXT_CACHE_EXPIRY = getattr(settings, 'SYSTEMTEXT_CACHE_EXPIRY',
                                  600)  # 10 min
SYSTEMTEXT_REBUILD_ON_SAVE = getattr(settings, 'SYSTEMTEXT_REBUILD_ON_SAVE',
                                     True)
SYSTEMTEXT_USE_DEFAULT_ON_EMPTY = getattr(settings, 'SYSTEMTEXT_USE_DEFAULT_ON_EMPTY',
                                          False)



from __future__ import unicode_literals

from django.db import models
from wagtail.wagtailcore.models import Site


class SystemString(models.Model):
    DEFAULT_GROUP = 'general'

    identifier = models.CharField(max_length=1024)
    string = models.CharField(max_length=1024, blank=True, null=True)
    group = models.CharField(max_length=255, default=DEFAULT_GROUP)

    site = models.ForeignKey(Site)

    created = models.DateTimeField(auto_now_add=True)
    updated = models.DateTimeField(null=True, blank=True)
    accessed = models.DateTimeField(null=True, blank=True)

    modified = models.BooleanField(default=False)

    class Meta:
        unique_together = ['identifier', 'site', 'group']

    def __unicode__(self):
        return unicode(identifier)



from django import template
from django.conf import settings
from django.template import Library, Node, TemplateSyntaxError, Variable
from django.template.base import TOKEN_TEXT, TOKEN_VAR, render_value_in_context
from django.utils import six, translation
from django.utils.safestring import SafeData, mark_safe

from wagtailsystemtext.utils import systemtext
from wagtailsystemtext.models import SystemString


register = template.Library()


class TranslateNode(Node):
    def __init__(self, filter_expression, group, asvar=None, default=None,
                 message_context=None):
        self.noop = True
        self.asvar = asvar
        self.default = default
        self.group = group
        self.message_context = message_context
        self.filter_expression = filter_expression
        if isinstance(self.filter_expression.var, six.string_types):
            self.filter_expression.var = Variable("'%s'" %
                                                  self.filter_expression.var)

    def render(self, context):
        self.filter_expression.var.translate = not self.noop
        if self.message_context:
            self.filter_expression.var.message_context = (
                self.message_context.resolve(context))
        output = self.filter_expression.resolve(context)

        value = render_value_in_context(output, context)

        # Restore percent signs. Percent signs in template text are doubled
        # so they are not interpreted as string format flags.
        is_safe = isinstance(value, SafeData)
        value = value.replace('%%', '%')
        value = systemtext(value, group=self.group, default=self.default)
        value = mark_safe(value) if is_safe else value
        if self.asvar:
            context[self.asvar] = value
            return ''
        else:
            return value


@register.tag("systemtext")
def do_systemtext(parser, token):
    bits = token.split_contents()
    message_string = parser.compile_filter(bits[1])
    remaining = bits[2:]

    asvar = None
    default = None
    message_context = None
    seen = set()
    group = SystemString.DEFAULT_GROUP

    while remaining:
        option = remaining.pop(0)
        if option in seen:
            raise TemplateSyntaxError(
                "The '%s' option was specified more than once." % option,
            )
        elif option == 'group':
            value = remaining.pop(0)[1:-1]
            group = value
        elif option == 'default':
            value = remaining.pop(0)[1:-1]
            default = value
        elif option == 'as':
            try:
                value = remaining.pop(0)
            except IndexError:
                msg = "No argument provided to the '%s' tag for the as option." % bits[0]
                six.reraise(TemplateSyntaxError, TemplateSyntaxError(msg), sys.exc_info()[2])
            asvar = value
        else:
            raise TemplateSyntaxError(
                "Unknown argument for '%s' tag: '%s'. The only options "
                "available are 'noop', 'context' \"xxx\", and 'as VAR'." % (
                    bits[0], option,
                )
            )
        seen.add(option)

    return TranslateNode(message_string, group, asvar, default, message_context)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-20 14:50
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0030_index_on_pagerevision_created_at'),
    ]

    operations = [
        migrations.CreateModel(
            name='SystemString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identifier', models.CharField(max_length=1024)),
                ('string', models.CharField(blank=True, max_length=1024, null=True)),
                ('group', models.CharField(default='general', max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(blank=True, null=True)),
                ('accessed', models.DateTimeField(blank=True, null=True)),
                ('modified', models.BooleanField(default=False)),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='systemstring',
            unique_together=set([('identifier', 'site', 'group')]),
        ),
    ]
